#!/bin/sh

#################################
## IMPLEMENTATION INSTRUCTIONS ##
#################################

## 1: Edit the parameters in the "PARAMETERS" section
## 2: Choose "Reveal CCC Scripts folder" from CCC's Utilities menu (if you see "Secure CCC's Scripts folder" instead, choose that first)
## 3. Copy this script into the revealed Scripts folder
## 4: Choose "Secure CCC's Scripts folder" from CCC's Utilities menu
## 5. Select the applicable backup task in CCC's sidebar
## 6. Click the "Advanced Settings" button
## 7. Click the folder icon next to "Run a shell script" in the "Postflight" tab. Select this script
## 8. Save the task

#################################
########## PARAMETERS ###########
#################################
# the 60-second delay is intended to give CCC enough time to complete 
# postflight snapshot activity, which occurs after this script runs
delay=60

# Set this to 1 if the script should unmount the source
unmountSource=0

# Set this to 1 if the script should unmount the destination
unmountDest=0

# Set this to 1 if you want the script to eject, not just unmount the volumes
alsoEject=0


# Set these to 1 if the source or destination is a NAS volume
sourceIsNAS=0
destIsNAS=0

log="/Library/Application Support/com.bombich.ccc/pht_debug.log"

##### No changes required below this line #####

if [ "$unmountSource" -ne "0" ]; then
	devID=`df "$1" | awk '!/Filesystem/ {print $1}'`
	if [[ $devID == *"@/dev/disk"* ]]; then
		devID=`echo "$devID" | awk -F @ '{print $NF}'`
	fi
	
	if [ "$sourceIsNAS" -ne "0" ]; then
		echo "Unmounting and ejecting $devID"
		umount "$devID"
	else
		# The delays here give CCC enough time to unmount and remove any transient source snapshots
		if [ "$alsoEject" -ne "0" ]; then
			if [ "$devID" != "" ]; then
				echo "Unmounting and ejecting $devID"
				(sleep 5; diskutil unmountDisk "$devID"; diskutil eject "$devID") &
				
			else
				echo "Unmounting and ejecting $1"
				(sleep 5; diskutil eject "$1") &
			fi
		else
			echo "Unmounting $devID"
			(sleep 5; diskutil unmount "$devID") &
		fi
	fi
fi

if [ "$unmountDest" -ne "0" -a "$2" != "" ]; then
	devID=`df "$2" | awk '!/Filesystem/ {print $1}'`
	if [ "$destIsNAS" -ne "0" ]; then
		echo "Unmounting and ejecting $devID"
		umount "$devID"
	else
		if [ "$alsoEject" -ne "0" ]; then
			if [ "$devID" != "" ]; then
				(sleep $delay; echo "Unmounting and ejecting $devID" >> "$log"; diskutil unmountDisk "$devID" >> "$log" 2>&1; diskutil eject "$devID" >> "$log" 2>&1) &
			else
				(sleep $delay; echo "Unmounting and ejecting $2" >> "$log" 2>&1; diskutil eject "$2" >> "$log" 2>&1; if [ $? -ne 0 ]; then diskutil unmountDisk "$2" >> "$log" 2>&1; fi) &
			fi
		else
			(sleep $delay; echo "Unmounting $devID" >> "$log" 2>&1; diskutil unmount "$devID" >> "$log" 2>&1) &
		fi
	fi
fi